# Makes FIGURE 2 in Hurford et al.

# The results of the simulation R0Calcs.R are loaded
# since this simulation takes a while to run by
# itself

# You will need to set the working directory to find the file Summary.Rdata
setwd('~/Desktop/Code')
# Loads the file with the data to make graphs. This file is produced by Figure2_R0Calcs.R
load("Summary.Rdata")

# Here there is some reordering to get the x-axis
# to have the warmer sites first and the colder
# sites last. Also note that every odd index corresponds
# to the full model, where the even numbers are the
# same site when ignoring temporal variability.

par(mfrow=c(3,2), mar=c(4.5,4,1,1.5))
# Floquet
barplot(c(Summary$FVal[c(13,19,21,1,3,5,9,7,11,15,17)],0),names.arg = c("CH", "IM3", "IM4", "BCB","BCV", "BCC", "NB","NS", "(NL)", "NIN", "NLI", "NL"), col=c("deepskyblue","darkorange", "forestgreen", "blue4", "dodgerblue","deepskyblue","darkred","darkorange", "darkgoldenrod1", "blue4", "red3", "darkgoldenrod1"),ylim=c(0,0.03), main = "Floquet exponent", las=3)
# Graph of critical stocking density
barplot(Summary$fcrit[c(13,19,21,1,3,5,9,7,11,15,17)]/1e5,names.arg = c("CH", "IM3", "IM4", "BCB","BCV", "BCC", "NB","NS", "(NL)", "NIN", "NLI"), col=c("deepskyblue","darkorange", "forestgreen", "blue4", "dodgerblue","deepskyblue","darkred","darkorange", "darkgoldenrod1", "blue4", "red3"),ylim=c(0,3.5), main = "Critical stocking density", las=3)

#Linear regression R0 vs mu: temporal variation is considered
mod = lm(Summary$R0Val[c(1,3,5,7,9,11,13,15,17,19,21)]~Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)])
plot(Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)], Summary$R0Val[c(1,3,5,7,9,11,13,15,17,19,21)], type="n", ylab = "", xlab = "", ylim = c(1,3), xlim = c(0,.035), bty="l", main = "R0 vs. Floquet exponent", las =3)
abline(mod)
text(Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)],Summary$R0Val[c(1,3,5,7,9,11,13,15,17,19,21)],c("BCB","BCV", "BCC", "NS","NB", "(NL)", "CH", "NIN", "NLI", "IM3", "IM4"), col=c("blue4", "dodgerblue","deepskyblue","darkorange","darkred", "darkgoldenrod1", "deepskyblue", "blue4", "red3", "darkorange", "forestgreen"))

#Linear regression: Critical stocking density vs. mu temporal variation is considered
fcrit2=log(Summary$fcrit[c(1,3,5,7,9,11,13,15,17,19,21)]/1e5)
mod2 = lm(fcrit2~Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)])
plot(Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)], Summary$fcrit[c(1,3,5,7,9,11,13,15,17,19,21)]/1e5, type="n", ylab = "", xlab = "", ylim = c(0,3.5), xlim = c(0,.035), bty="l", main = "Crit. stocking dens. vs. Floquet exp.", las = 3)
text(Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)],Summary$fcrit[c(1,3,5,7,9,11,13,15,17,19,21)]/1e5,c("BCB","BCV", "BCC", "NS","NB", "(NL)", "CH", "NIN", "NLI", "IM3", "IM4"), col=c("blue4", "dodgerblue","deepskyblue","darkorange","darkred", "darkgoldenrod1", "deepskyblue", "blue4", "red3", "darkorange", "forestgreen"))
vec = seq(0,0.035,0.001)
lines(vec, exp(1.18 - 59.39*vec))

# Ignoring termporal variability in floquet exponent (mu)
plot(Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)], Summary$FVal[c(2,4,6,8,10,12,14,16,18,20,22)], type="n",xlim=c(0,.035), bty="l", ylim=c(0,.03), ylab="", xlab="", main = "Effect of seasonality: Floquet exp.", las =3)
lines(c(0,.035), c(0,.035), lty=2)
text(Summary$FVal[c(1,3,5,7,9,11,13,15,17,19,21)],Summary$FVal[c(2,4,6,8,10,12,14,16,18,20,22)],c("BCB","BCV", "BCC", "NS","NB", "(NL)", "CH", "NIN", "NLI", "IM3", "IM4"), col=c("blue4", "dodgerblue","deepskyblue","darkorange","darkred", "darkgoldenrod1", "deepskyblue", "blue4", "red3", "darkorange", "forestgreen"))
# Ignoring temporal variability in stocking denisty
plot(Summary$fcrit[c(1,3,5,7,9,11,13,15,17,19,21)]/1e5,Summary$fcrit[c(2,4,6,8,10,12,14,16,18,20,22)]/1e5, type="n", bty="l", xlab="", ylab="", main = "Effect of seasonality: Crit. stocking dens.", ylim = c(0,4.5), xlim = c(0,3.5), las=3)
text(Summary$fcrit[c(1,3,5,7,9,11,13,15,17,19,21)]/1e5,Summary$fcrit[c(2,4,6,8,10,12,14,16,18,20,22)]/1e5,c("BCB","BCV", "BCC", "NS","NB", "(NL)", "CH", "NIN", "NLI", "IM3", "IM4"), col=c("blue4", "dodgerblue","deepskyblue","darkorange","darkred", "darkgoldenrod1", "deepskyblue", "blue4", "red3", "darkorange", "forestgreen"))
lines(c(0,4.5), c(0,4.5), lty=2)

# Calculations related to the critical stocking density for Frazer et al.Critical thresholds in sea
# lice epidemics: evidence, sensitivity and subcritical estimation
17.3*1000*1000/125517/26
113235*5.3*26/1000/1000


