# Makes FIGURE 4 of Hurford et al.
# Finds the generation time for different salmon farming sites
# Day 1 corresponds to Jan 1, 2000.
# Clearing Workspace and loading packages
rm(list = ls())
library(PBSddesolve)

# You will need to set your working directory so that the .Rdata files can be located.
#setwd('~/Desktop/Code')
# Loads the functions relating life history to temperature and salinity

load("ParamsFuncs.RData")

# Set t0 = 0
t0<-0

# Temperature and salinity as periodic functions
Temp = function(t){
    Temp = a + b1*sin(2 * pi * t/365) + b2*cos(2 * pi * t/365)
    return(Temp)
  }
S = function(t){
    S = c + d1*sin(2 * pi * t/365) + d2*cos(2 * pi * t/365)
    return(S)
} 

# The function delays()
# creates 2 year of information on the time delays, with 1 year of
# burn in time to get rid of any artifacts due to the initial history.
delays=function(){
  tp0 <- tpINIT()
  tc0 <- tcINIT()
  ## Function to calculate the gradient
  delayfun = function(t, y){
    tp = y[1]
    # The time delay for the chalimus stage
    tc = y[2]
    tp1 = 1 - gammaP(Temp(t))/gammaP(Temp(t-tp))
    tc1 = 1 - gammaC(Temp(t))/gammaC(Temp(t-tc))
    return(c(tp1, tc1))
  }
  # List of all initial Values
  yinit = c(tp0,tc0)
  # Run Model
  x = dde(y = yinit, func = delayfun, times = seq(-365, 2*365, 1), hbsize = 1000000)
  return(x)
}

# Creatling mu(t) rather than mu(S).
muat=function(t){
    mua(S(t))
}

# Calculating the time of laying, hatching, becoming a copepodid and becoming a chalimus,
# requires identify the correct elements in the vector reporting the length of the delays
timeCIP = function(timeA){
# Time of becoming a chalimus
timeC = timeA-x$y2[min(which(x$time>=timeA))]
# Time of becoming a chalimus. In Tucker they state the duration of the copepodid stage as 10 days.
timeI = timeC - 10
# Time of becoming a nauplii
timeP = timeI - x$y1[min(which(x$time>=timeI))]
return(c(timeP, timeI, timeC))
}

# consider a sequence of times when the louse becomes an adult.
tAvec = seq(365,2*365)
# Time of hatching modulus 365 (preallocation)
timePmod = matrix(ncol=11,nrow=366)
# Time of becoming a chalimus (preallocation)
timeCmod = timePmod
# More preallocation below...
timetoC = timePmod
timetoA = timePmod
tempP = timePmod
tempC = timePmod
timeCtoA = timePmod

# Perform the calculations for all 11 sites
for(j in seq(1,11)){
  if(j==1){
load('farm24.Rdata')
    t0<-0
    x<-delays()}
  if(j==2){
load('farmNL.Rdata')
    x<-delays()}
if(j==3){
load('farmWCVI.Rdata')
x<-delays()}
  if(j==4){
    load('farmCC.Rdata')
    t0<-0
    x<-delays()}
  if(j==5){
    load('farmNB.Rdata')
    x<-delays()}
  if(j==6){
    load('farmNS.Rdata')
    x<-delays()}
  if(j==7){
    load('farmCH.Rdata')
    x<-delays()}
  if(j==8){
    load('farmNIN.Rdata')
    x<-delays()}
  if(j==9){
    load('farmNLI.Rdata')
    x<-delays()}
  if(j==10){
    load('farmIM3.Rdata')
    x<-delays()}
  if(j==11){
    load('farmIM4.Rdata')
    x<-delays()}
for(i in seq(1,length(tAvec))){
  # Time of becoming an adult
  timeA<-tAvec[i]
  x2=timeCIP(timeA)
  # Time of becoming a nauplii
  timeP = x2[1]
  # Time of becoming a chalimus
  timeC = x2[3]
  # Time from hatching to adult
  timetoA[i,j] = timeA-timeP
  # Time from hatching to chalimus
  timetoC[i,j] = timeC-timeP
  # Day of the year when hatched
  timePmod[i,j] = timeP%%365
  # Day of the year when chalimus
  timeCmod[i,j] = timeC%%365
  # Time from chalimus to adult
  timeCtoA[i,j] = timeA-timeC
  # Temperature at hatching
  tempP[i,j] = Temp(timePmod[i,j])
  # Temperature when becoming chalimus
  tempC[i,j] = Temp(timeCmod[i,j])
}
}

par(mfrow=c(4,3), mar=c(3, 3, 2, 1))
# We plot the warm sites on the first row. There is a bit of messing around here to get the
# times into modulus 365 and then to order the times within the vectors.
plot(timePmod[order(timePmod[,7]),7],timetoC[order(timePmod[,7]),7], col="deepskyblue",lwd=2, main = "Chile (CH)", typ="l", ylim = c(0,50), xaxt = "n", xlab= "", ylab="")
lines(timeCmod[order(timeCmod[,7]),7],timeCtoA[order(timeCmod[,7]),7], col="deepskyblue",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))
plot(timePmod[order(timePmod[,10]),10],timetoC[order(timePmod[,10]),10], col="darkorange",lwd=2,main = "Ireland (IM3)", typ="l", ylim = c(0,50), xaxt = "n", xlab= "", ylab="")
lines(timeCmod[order(timeCmod[,10]),10],timeCtoA[order(timeCmod[,10]),10], col="darkorange",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))
plot(timePmod[order(timePmod[,11]),11],timetoC[order(timePmod[,11]),11], col="forestgreen",lwd=2,  typ="l", ylim = c(0,50), xaxt = "n", xlab= "", ylab="", main = "Ireland (IM4)")
lines(timeCmod[order(timeCmod[,11]),11],timeCtoA[order(timeCmod[,11]),11], col="forestgreen",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))

# Now were doing the same for the BC sites, these appear in row 2
plot(timePmod[order(timePmod[,1]),1], timetoC[order(timePmod[,1]),1],col = "blue4", lwd=2, typ="l", ylim = c(0,50), xaxt = "n", xlab= "", ylab="", main = "British Columbia (BCB)")
lines(timeCmod[order(timeCmod[,1]),1],timeCtoA[order(timeCmod[,1]),1], col="blue4",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))
plot(timePmod[order(timePmod[,4]),4], timetoC[order(timePmod[,4]),4], col = "deepskyblue", lwd=2,  typ="l", ylim = c(0,50), xaxt = "n", xlab= "", ylab="", main = "British Columbia (BCC)")
lines(timeCmod[order(timeCmod[,4]),4],timeCtoA[order(timeCmod[,4]),4], col="deepskyblue",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))
plot(timePmod[order(timePmod[,3]),3], timetoC[order(timePmod[,3]),3], col = "dodgerblue", lwd=2, typ="l", ylim = c(0,50), xaxt = "n", xlab= "", ylab="", main = "British Columbia (BCV)")
lines(timeCmod[order(timeCmod[,3]),3],timeCtoA[order(timeCmod[,3]),3], col="dodgerblue",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))

# Now the colder sites
plot(timePmod[order(timePmod[,5]),5], timetoC[order(timePmod[,5]),5], col = "darkred", lwd=2, ylim = c(0,50), typ="l", main="New Brunswick (NB)", ylab="", xlab="", xaxt="n")
lines(timeCmod[order(timeCmod[,5]),5],timeCtoA[order(timeCmod[,5]),5], col="darkred",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))
plot(timePmod[order(timePmod[,6]),6], timetoC[order(timePmod[,6]),6], col = "darkorange", lwd=2, ylim = c(0,50), typ="l", main="Nova Scotia (NS)", ylab="", xlab="", xaxt="n")
lines(timeCmod[order(timeCmod[,6]),6],timeCtoA[order(timeCmod[,6]),6], col="darkorange",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))

plot(timePmod[order(timePmod[,2]),2], timetoC[order(timePmod[,2]),2], col = "darkgoldenrod1", lwd=2, ylim = c(0,50), typ="l", main="Newfoundland (NL)", ylab="", xlab="", xaxt="n")
lines(timeCmod[order(timeCmod[,2]),2],timeCtoA[order(timeCmod[,2]),2], col="darkgoldenrod1",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))
plot(timePmod[order(timePmod[,8]),8],timetoC[order(timePmod[,8]),8], col="blue4",lwd=2, ylim = c(0,50), typ="l", main="Norway (NIN)", ylab="", xlab="", xaxt="n")
lines(timeCmod[order(timeCmod[,8]),8],timeCtoA[order(timeCmod[,8]),8], col="blue4",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))
plot(timePmod[order(timePmod[,9]),9],timetoC[order(timePmod[,9]),9], col="red3",lwd=2, ylim = c(0,50), typ="l", main="Norway (NLI)", ylab="", xlab="", xaxt="n")
lines(timeCmod[order(timeCmod[,9]),9],timeCtoA[order(timeCmod[,9]),9], col="red3",lwd=2)
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"))

#####
# Now we want to plot with temperature on the x-axis instead of time for the initial
# treatment.
Tvec = seq(0, 16,.1)
par(mfrow=c(1,1), mar=c(3, 3, 1, 1))
plot(tempP[order(tempP[,1]),1], timetoC[order(tempP[,1]),1], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "blue4", pch=19)
points(tempC[order(tempC[,1]),1], timeCtoA[order(tempC[,1]),1], col = "blue4", pch = 19)
points(tempP[order(tempP[,2]),2], timetoC[order(tempP[,2]),2], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "darkgoldenrod1", pch=19)
points(tempC[order(tempC[,2]),2], timeCtoA[order(tempC[,2]),2], col = "darkgoldenrod1", pch = 19)
points(tempP[order(tempP[,3]),3], timetoC[order(tempP[,3]),3], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "dodgerblue", pch=19)
points(tempC[order(tempC[,3]),3], timeCtoA[order(tempC[,3]),3], col = "dodgerblue", pch = 19)
points(tempP[order(tempP[,4]),4], timetoC[order(tempP[,4]),4], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "deepskyblue", pch=19)
points(tempC[order(tempC[,4]),4], timeCtoA[order(tempC[,4]),4], col = "deepskyblue", pch = 19)
points(tempP[order(tempP[,5]),5], timetoC[order(tempP[,5]),5], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "darkred", pch=19)
points(tempC[order(tempC[,5]),5], timeCtoA[order(tempC[,5]),5], col = "darkred", pch = 19)
points(tempP[order(tempP[,6]),6], timetoC[order(tempP[,6]),6], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "darkgoldenrod1", pch=19)
points(tempC[order(tempC[,6]),6], timeCtoA[order(tempC[,6]),6], col = "darkgoldenrod1", pch = 19)
points(tempP[order(tempP[,7]),7], timetoC[order(tempP[,7]),7], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "deepskyblue", pch=19)
points(tempC[order(tempC[,7]),7], timeCtoA[order(tempC[,7]),7], col = "deepskyblue", pch = 19)
points(tempP[order(tempP[,8]),8], timetoC[order(tempP[,8]),8], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "blue4", pch=19)
points(tempC[order(tempC[,8]),8], timeCtoA[order(tempC[,8]),8], col = "blue4", pch = 19)
points(tempP[order(tempP[,9]),9], timetoC[order(tempP[,9]),9], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "red3", pch=19)
points(tempC[order(tempC[,9]),9], timeCtoA[order(tempC[,9]),9], col = "red3", pch = 19)
points(tempP[order(tempP[,10]),10], timetoC[order(tempP[,10]),10], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "darkorange", pch=19)
points(tempC[order(tempC[,10]),10], timeCtoA[order(tempC[,10]),10], col = "darkorange", pch = 19)
points(tempP[order(tempP[,11]),11], timetoC[order(tempP[,11]),11], xlim = c(0,16), ylim = c(0,50), xlab ="", ylab = "", col = "forestgreen", pch=19)
points(tempC[order(tempC[,11]),11], timeCtoA[order(tempC[,11]),11], col = "forestgreen", pch = 19)

# This plots the approximation given in equations 3 and 4 of Hurford et al.
lines(Tvec, 1/gammaP(Tvec)+10, lwd=5, lty=2)
lines(Tvec, 1/gammaC(Tvec), lwd=5, lty=2)
Tvec = seq(17.8,18,0.01)
# Here we are trying to numerically verify the temperature where the time from C to A is
# greater then the time from hatching to C.
plot(Tvec, 1/gammaP(Tvec)+10-1/gammaC(Tvec),typ="l")
lines(c(17,18), c(0,0))
