# Makes FIGURE S3 of Hurford et al., which tests the numerical methods
# for determining the leading eigenvalue of the Poincare map

# Clearing Workspace and loading packages
rm(list = ls())
require(PBSddesolve)

# Change the working directory so your code can find the dependent .Rdata
# files
#setwd('~/Desktop/Code')
load("ParamsFuncs.RData")
# This is the value of iota for the manuscript
iota<-2.076622e-09
# This example is for the farm BCB
load('farm24.Rdata')

# This is the function that performs the numerical integration
sealice=function(t0,tfin,A0,C0,I0,P0){
  # Functions for temperature and salinity
  Temp = function(t){
    Temp = a + b1*sin(2 * pi * t/365) + b2*cos(2 * pi * t/365)
    return(Temp)
  }
  S = function(t){
    S = c + d1*sin(2 * pi * t/365) + d2*cos(2 * pi * t/365)
    return(S)
  } 
  
  ## Function to calculate the gradient
  lice = function(t, y){
    # The number of adult females
    A = y[1]
    # The number of plaktonic larvae
    P = y[2]
    # The time delay for the planktonic stage
    tp = y[3]
    # The number of infectious copepodids
    I = y[4]
    # The number of chalimus
    C = y[5]
    # The time delay for the chalimus stage
    tc = y[6]
    # Mortality durign the planktonic stage
    PhiP = y[7]
    # Mortality during the chalimus stage
    PhiC = y[8]
    
    # Apply timelags only once enough history has been established:
    if (t - tp < t0) {
      # The value of the lagged variables. Setting them equal to 0 means no lag.
      lagp = yinit
    } else{
      # if the logical test passses we can calculate the lags
      lagp = pastvalue(t - tp)
    }
    
    if (t - tc < t0) {
      # The value of the lagged variables. Setting them equal to 0 means no lag.
      lagc = yinit
    } else{
      # if the logical test passses we can calculate the lags
      lagc = pastvalue(t - tc)
    }
    
    # The system of DDEs
    P1 =  eta(Temp(t))*epsilon(Temp(t))*A*V(Temp(t),S(t))-eta(Temp(t-tp))*epsilon(Temp(t-tp))*lagp[1]*(gammaP(Temp(t))/gammaP(Temp(t-tp)))*V(Temp(t-tp),S(t-tp))*PhiP-mup(S(t))*P
    I1 =  eta(Temp(t-tp))*epsilon(Temp(t-tp))*lagp[1]*(gammaP(Temp(t))/gammaP(Temp(t-tp)))*V(Temp(t-tp),S(t-tp))*PhiP-iota*f*I-mui(S(t))*I
    C1 = iota*f*I-iota*f*lagc[4]*(gammaC(Temp(t))/gammaC(Temp(t-tc)))*PhiC-muc(S(t))*C
    A1 = ((iota*f*lagc[4]*(gammaC(Temp(t))/gammaC(Temp(t-tc)))*PhiC)/2)-mua(S(t))*A
    
    tp1 = 1 - gammaP(Temp(t))/gammaP(Temp(t-tp))
    tc1 = 1 - gammaC(Temp(t))/gammaC(Temp(t-tc))
    
    PhiP1 = PhiP*(gammaP(Temp(t))*mup(S(t-tp))/gammaP(Temp(t-tp))-mup(S(t)))
    PhiC1 = PhiC*(gammaC(Temp(t))*muc(S(t-tc))/gammaC(Temp(t-tc))-muc(S(t)))
    return(c(A1, P1, tp1, I1, C1, tc1, PhiP1, PhiC1))
  }
  # List of all paremeter Values
  parameters = c(eta, epsilon, iota, V, mup, mui, muc, mua, t0, tfin, mup, f)
  # Initial values calculated from their integral definitions: see the manuscript for
  # details
  tp0 = tpINIT()
  tc0 = tcINIT()
  PhiP0 = exp(-(integrate(mortalityP, t0 - tp0, t0)$value))
  PhiC0 = exp(-(integrate(mortalityC, t0 - tc0, t0)$value))
  # List of all initial Values
  yinit <- c(A0, P0, tp0, I0, C0, tc0, PhiP0, PhiC0);
  x = dde(y = yinit, func = lice, parms = parameters, times = seq(t0, tfin, 1), hbsize = 1000000)
  return(x)
}

# The reported critical stocking density for BCB
fcrit<-125512.59
A0=1
I0=1
P0=1
C0=1
t0<-0

# Consider 3 different values of f.
f<-fcrit
x = sealice(0,10*365, A0,C0,I0,P0)
f<-fcrit+1e2
xp= sealice(0,10*365,A0,C0,I0,P0)
f<-fcrit-1e2
xn = sealice(0,10*365,A0,C0,I0,P0)

# Plot the results
par(mfrow=c(1,1), mar=c(5,5,1,1))
plot(xp$time/365, xp$y1, typ="l", col="blue", ylab = "A(t)", xlab="time (years)", lwd=3, xlim = c(0,10), ylim=c(.5,.7), cex.lab = 1.3, cex.axis=1.3)
lines(xn$time/365, xn$y1, col = "orange", xlim = c(0,10), ylim=c(.5,1),typ="l", lwd=3)
lines(x$time/365, x$y1, col = "black", xlim = c(0,10), ylim=c(.5,1), lwd=3)
lines(c(0,10), c(0.687,0.687))
