# Data from Bravo et al. 2008. are fit with an exponential decrease function
# to estimate the mortality rate at different salinities from 4 different
# locations in Chile. Data are from Table 1.

# The data from these analyses appear as green squares with triangles
# in Figure S.1i.

# Bravo et al. 2008. The tolerance of Caligus rogercresseyi to salinity reduced in
# southern Chile. Bulletin European Association of Fish Pathologists. 28(5): 198-206.

#####################
# Vectors of salinity values
salvec = c(5, 10, 15, 20)
salvec2 = c(10, 15, 20)
par(mfrow =c(2,2))

# Pto Montt
# 5 ppt
time = c(.5, 1, 12, 18, 24)/24
p = c(.5, .45, .3, .3, .3)
logp = -log(p)
# Fitting an exponential decay function with intercept forced through 1.
fit <- lm(logp~time+0)
plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)", main = "Pto Montt")
abline(fit)
mu = coef(fit)

# 10ppt
 p = c(.95, .95, .7, .7, .15)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu, coef(fit))
 
 # 15 ppt
 p = c(.95, .95, .7, .65, .4)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
 
 # 20 ppt
 p=c(1, 1, .8, .65, .65)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 
 # Saving all exponential decay coefficients in a vector
 mu = c(mu,coef(fit))
 mu1 = mu

 ########
 # Ancund-Catro
 # 10 ppt
 p = c(.95, .9, .35, .25, .2)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)", main = "Ancund-Catro")
 abline(fit)
 mu = coef(fit)
 
 # 15 ppt
 p = c(1, .95, .4, .3, .2)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
 
 # 20 ppt
 p = c(1, .9, .7, .45, .4)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
mu2 = mu

 #An empty panel
 plot(-100,0,xlim=c(0,1), ylim = c(0,1), xlab="", ylab="",xaxt = "n", yaxt = "n",bty="n")
 
 ##################
 # Quellon
 # 10 ppt
 p=c(1,.95, .55, .35, .25)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)", main = "Quellon")
 abline(fit)
 mu = coef(fit)
 
 # 15ppt
 p=c(1, .95, .85, .5, .5)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
 
 # 20ppt
 p=c(1, 1, 1, .95, .95)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
 mu3 = mu
 
 #An empty panel
 plot(-100,0,xlim=c(0,1), ylim = c(0,1), xlab="", ylab="",xaxt = "n", yaxt = "n",bty="n")
 
 ######################
 # Hornopire
 # 5 ppt
 p = c(.8, .8, .4, .25, .15)
 logp = -log(p)
 fit <- lm(logp~time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)", main = "Hornopire")
 abline(fit)
 mu = coef(fit)
 
 # 10 ppt
 p = c(1, 1, .5, .5, .45)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
 
 # 15 ppt
 p = c(1, .95, .8, .8, .8)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
 
 # 20 ppt
 p = c(.95, .9, .85, .85, .8)
 logp = -log(p)
 fit <- lm(logp ~ time+0)
 plot(time,logp, ylim = c(0,1.2), ylab = "-log(p)", xlab = "time (days)")
 abline(fit)
 mu = c(mu,coef(fit))
 
 ###### Fitting the same function to the salinity vs. mu_A data as used in
 # Connors et al. for L. salmonis.
 salinity = seq(0,20,.1)
 fit1 = lm(log(mu1)~salvec)
 fit2 = lm(log(mu2)~salvec2)
 fit3 = lm(log(mu3)~salvec2)
 fit = lm(log(mu)~salvec)
 
 par(mfrow=c(1,1))
 # Pto Montt - blue
 plot(salvec, mu1, ylab = "mu_A", ylim = c(0,3), xlab = "salinity, ppt", xlim = c(0,20), col = "blue")
 lines(salinity, exp(coef(fit1)[1] + coef(fit1)[2]*salinity), col = "blue")
 # Ancund-Catro - red
 points(salvec2, mu2, xlim = c(5,20), ylim = c(0, 2), pch = 15, col = "red")
 lines(salinity, exp(coef(fit2)[1] + coef(fit2)[2]*salinity), col = "red")
 # Quellon - green
 points(salvec2, mu3, xlab = "salinity, psu", ylab = "mu_A", ylim = c(0,2), xlim = c(5, 20), pch = 2, col = "green")
 lines(salinity, exp(coef(fit3)[1] + coef(fit3)[2]*salinity), col = "green")
 #  # Hornopire - black
 points(salvec, mu, xlab = "salinity, psu", ylim = c(0,2), pch = 17)
 lines(salinity, exp(coef(fit)[1] + coef(fit)[2]*salinity))
 